@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class NeurobankConfig(AppConfig):
-    name = 'nbank_registry'
+    name = "nbank_registry"
