@@ -9,9 +9,8 @@ class MissingFileError(NotAvailableForDownloadError):
 
     def __str__(self):
         return (
-                f"Could not find resource '{self.resource}' in directory"
-                f" {self.path}."
-               )
+            f"Could not find resource '{self.resource}' in directory" f" {self.path}."
+        )
 
 
 class NotAFileError(NotAvailableForDownloadError):
@@ -21,17 +20,18 @@ class NotAFileError(NotAvailableForDownloadError):
 
     def __str__(self):
         return (
-                f"Resource '{self.resource}' was found in directory"
-                f" {self.path}, but it is not a file, so it cannot be"
-                " downloaded"
-               )
+            f"Resource '{self.resource}' was found in directory"
+            f" {self.path}, but it is not a file, so it cannot be"
+            " downloaded"
+        )
+
 
 class SchemeNotImplementedError(NotAvailableForDownloadError):
     def __str__(self):
         return (
-                "The requested resource is stored in an archive that"
-                " uses a scheme that is not supported by this registry"
-               )
+            "The requested resource is stored in an archive that"
+            " uses a scheme that is not supported by this registry"
+        )
 
 
 class NonDownloadableDtypeError(NotAvailableForDownloadError):
